@@ -344,7 +344,7 @@ class Deposits:
                 else:
                     start_basis = qle.StartBasis.spot
                 helper = ql.DepositRateHelper(rate.rate/100, 
-                                            ql.Period(rate.tenor), 
+                                            ql.Period('1D'), 
                                             start_basis, 
                                             self.__qlcalendar, 
                                             business_day, 
@@ -495,28 +495,75 @@ class IBOR:
 
 class OIS:
     def __init__(self, rates: List[pymodels.Rate],
-                index=None, qlcalendar=None):
+                setting:pymodels.DepoSetting=None, index=None, 
+                qlcalendar=None, date:str=None):
         self.__rates = rates
         #self.__setting = setting
         #self.__current_date = current_date
         if index:
             self.__index = index
+        if setting:
+            self.__setting = setting
+        else:
+            self.__setting = None
 
         if qlcalendar:
             self.__qlcalendar = qlcalendar
         else:
             self.__qlcalendar = ql.NullCalendar()    
-    
+
+        if date:
+            self.__date=date
+        else:
+            self.__date = ql.Settings.instance().evaluationDate.ISO()
+
 
     def helpers(self):
-        ois_helpers = []
-        for rate in self.__rates:
-            ois_helper = ql.OISRateHelper(2, 
-                                        ql.Period(rate.tenor),
-                                        ql.QuoteHandle(ql.SimpleQuote(rate.rate/100)), 
-                                        self.__index)
-            ois_helpers.append(ois_helper)
-        return ois_helpers
+        
+        if self.__setting:
+            setting = self.__setting
+            cal = self.__qlcalendar
+            if self.__date:
+                today = ql.Date(self.__date, '%Y-%m-%d')
+            else:
+                today = ql.Settings.instance().evaluationDate
+            
+            start_date = cal.advance(today, 
+                            ql.Period(setting.start_basis, ql.Days), 
+                            qlc.ql_business_day[setting.business_day], 
+                            False)
+            #print('start_date:',start_date)
+            ois_helpers = []
+            for rate in self.__rates:
+                if rate.tenor in ['1W', '2W', '3W']:
+                    eom = False
+                else:
+                    eom = setting.eom
+                
+                end_date = cal.advance(start_date, 
+                        ql.Period(rate.tenor), 
+                        qlc.ql_business_day[setting.business_day], 
+                        eom)
+                ois_helper = ql.DatedOISRateHelper(start_date, 
+                                                        end_date, 
+                                                        ql.QuoteHandle(ql.SimpleQuote(rate.rate/100)),
+                                                        self.__index)
+                
+                ois_helpers.append(ois_helper)
+            return ois_helpers
+
+        else:
+            ois_helpers = []
+            for rate in self.__rates:
+                ois_helper = ql.OISRateHelper(2, 
+                                            ql.Period(rate.tenor),
+                                            ql.QuoteHandle(ql.SimpleQuote(rate.rate/100)), 
+                                            self.__index)
+                ois_helpers.append(ois_helper)
+            return ois_helpers
+
+
+    
 
 
 class IRS:
@@ -611,9 +658,9 @@ class Curve:
         self.__irs = irs  
 
 
-    def piecewise(self, date: dt64 = None):
+    def piecewise(self, date: str = None):
         if date:
-            vdate = ql.Date(datestr(date), '%Y-%m-%d')
+            vdate = ql.Date(date, '%Y-%m-%d')
         else:
             vdate = ql.Settings.instance().evaluationDate
         
